package com.yeejoin.amos.fas.business.dao.repository;

import java.util.List;

import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import com.yeejoin.amos.fas.dao.entity.TopographyLine;

@Repository("iTopographyLineDao")
public interface ITopographyLineDao  extends BaseDao<TopographyLine, Long> {

	List<TopographyLine> findByAppIdAndType(String appId,String type);

	TopographyLine findById(String id);

	@Query(value = "select * from f_topography_line " + " where `from` = (?1) or `to` = (?1)",nativeQuery = true)
	List<TopographyLine> findByKey(String key);

	List<TopographyLine> findByType(String type);

}
